XLIFF — Translate Toolkit 2.5.0 documentation

# XLIFF

XLIFF[*] is the OASIS standard for translation.

[*] | XML Localization Interchange File Format

## References

- XLIFF Standard
- OASIS XLIFF Technical Committee website

### Flavours

XLIFF also has documents that specify the conversion from various standard source documents and localisation formats.

- PO – For conformance to the po2xliff spec, see xliff2po.
  - Draft XLIFF 1.2 Representation Guide for Gettext PO
- HTML – not implemented
  - Draft XLIFF 1.2 Representation Guide for HTML
- Java (includes .properties and Java resource bundles) – not implemented
  - Draft XLIFF 1.2 Representation Guide for Java Resource Bundles
- ICU Resource Bundles – not officially being developed by XLIFF – Proposed representation guide

### Standard conformance

## Done

- File creation and parsing
- API can create multiple files in one XLIFF (some tools only read the first file)
- source-language attribute
- trans-unit with
    - note: addnote() and getnotes()
    - state
        - fuzzy: isfuzzy() and markfuzzy()
        - translated: marktranslated()
        - approved
        - needs-review-translation: isreview(), markreviewneeded()
    - id: setid()
    - context-group: createcontextgroup()
- context groups
- alt-trans

### XLIFF and other tools

Here is a small report on XLIFF support by Windows programs.